=======
History
=======

2.1.1 (2021-01-04)
------------------
* Fix tests

2.1.0 (2021-01-04)
------------------
* Add non EV attributes
* Fix UA string

2.0.1 (2020-04-21)
------------------
* flake8 fixes

2.0.0 (2020-04-21)
------------------
* Support new Azure based login. Thanks to @jaygun and me@lukecyca.com for core logic. Fixes issue #11

1.2.0 (2019-01-02)
------------------
* Support CA urls
* Reduce implicit retries

1.1.0 (2018-12-13)
------------------
* add explicit charging property

1.0.0 (2018-12-03)
------------------
* remove the selenium requirement (thanks starbuddy1995@gmail.com)
* get my.chevy working with the new website (thanks starbuddy1995@gmail.com)

0.4.0 (2018-05-09)
------------------
* my.chevy website is finally back up, data structure parsing adjusted to match it

0.3.2 (2018-02-04)
------------------

* Add simple unit testing
* Stop testing on python 3.4 so we can use more advanced exceptions

0.3.1 (2018-01-31)
------------------

* Nicer error handling when server throws an error

0.3.0 (2018-01-30)
------------------

* Change data collection to use json parsing instead of screen scraping after login

0.2.0 (2018-01-21)
------------------

* Upgraded cli to use `click`

0.1.0 (2017-12-31)
------------------

* First release on PyPI.
